CorrBin-package: Nonparameterics for correlated binary data
Description
This package implements nonparametric methods for analysing
exchangeable binary data with variable cluster sizes with
emphasis on trend testing. The input should specify the
treatment group, cluster-size, and the number of responses
(i.e. the number of cluster elements with the outcome of
interest) for each cluster.Details
ll{ Package: CorrBin
Type: Package
Version: 1.4
Date: 2013-01-13
License: GPL 2
LazyLoad: yes
} - The
CBDataandread.CBDatafunctions create a `CBData'
object used by the analysis functions. ran.CBDatacan be used to generate random
data with prespecified mean response and within-cluster
correlation.mc.test.chisqtests the
assumption of marginal compatibility underlying all the
methods, whilemc.estestimates the
distribution of the number of responses under marginal
compatibility.- Finally,
trend.testperforms three different tests for trend along the
treatment groups.
References
Szabo A, George EO. (2009) On the Use of Stochastic
Ordering to Test for Trend with Clustered Binary Data.
Biometrika
Stefanescu, C. & Turnbull, B. W. (2003) Likelihood
inference for exchangeable binary data with varying cluster
sizes. Biometrics, 59, 18-24
Pang, Z. & Kuk, A. (2007) Test of marginal compatibility
and smoothing methods for exchangeable binary data with
unequal cluster sizes. Biometrics, 63, 218-227