The actual work is performed by the geese function of
the geepack library. This function only provides a convenient wrapper
to obtain the results in the same format as RS.trend.test and
SO.trend.test.
The implementation aims for testing for increasing trend, and a
one-sided p-value is reported. The test statistic is asymptotically normally
distributed, and a two-sided p-value can be easily computed if needed.