Learn R Programming

CorrBin (version 1.5)

egde: EGDE data

Description

The data set is based on a developmental toxicity experiment on the effect of ethylene glycol diethyl ether (EGDE) on fetal development of New Zealand white rabbits. In the study, four groups of pregnant does were randomly assigned to dose levels $0, 25, 50$, and $100$ milligrams per kilogram body weight of EGDE. For each litter and at each dose level, the adverse response used is the combined number of fetal malformation and fetal death.

Usage

data(egde)

Arguments

Format

A 'CBData' object, that is a data frame with the following variables

Trt factor giving treatment group
ClusterSize the size of the litter
NResp the number of affected fetuses
Freq the number of litters with the given ClusterSize/NResp combination

Examples

Run this code
# NOT RUN {
  data(egde)
  stripchart(I(NResp/ClusterSize)~Trt, cex=sqrt(egde$Freq), data=egde, pch=1, 
             method="jitter", vertical=TRUE, ylab="Proportion affected")
# }

Run the code above in your browser using DataLab