Learn R Programming

CorrBin (version 1.5)

mc.test.chisq: Test the assumption of marginal compatibility

Description

mc.test.chisq tests whether the assumption of marginal compatibility is violated in the data.

Usage

mc.test.chisq(object, ...)

# S3 method for CMData mc.test.chisq(object, ...)

# S3 method for CBData mc.test.chisq(object, ...)

Arguments

object

a CBData or CMData object

other potential arguments; not currently used

Value

A list with the following components:

overall.chi

the test statistic; sum of the statistics for each group

overall.p

p-value of the test

individual

a list of the results of the test applied to each group separately:

  • chi.sq the test statistic for the group

  • p p-value for the group

Details

The assumption of marginal compatibility (AKA reproducibility or interpretability) implies that the marginal probability of response does not depend on clustersize. Stefanescu and Turnbull (2003), and Pang and Kuk (2007) developed a Cochran-Armitage type test for trend in the marginal probability of success as a function of the clustersize. mc.test.chisq implements a generalization of that test extending it to multiple treatment groups.

References

Stefanescu, C. & Turnbull, B. W. (2003) Likelihood inference for exchangeable binary data with varying cluster sizes. Biometrics, 59, 18-24

Pang, Z. & Kuk, A. (2007) Test of marginal compatibility and smoothing methods for exchangeable binary data with unequal cluster sizes. Biometrics, 63, 218-227

See Also

mc.est for estimating the distribution under marginal compatibility.

Examples

Run this code
# NOT RUN {
data(shelltox)
mc.test.chisq(shelltox)
data(dehp)
mc.test.chisq(dehp)
# }

Run the code above in your browser using DataLab