Learn R Programming

CorrBin (version 1.4)

mc.test.chisq.CMData: Test the assumption of reproducibility

Description

mc.test.chisq tests whether thee assumption of reproducibility is violated in the data.

Usage

## S3 method for class 'CMData':
mc.test.chisq(object, ...)

mc.test.chisq(object, ...)

## S3 method for class 'CBData':
mc.test.chisq(object, ...)

Arguments

object
a CBData or CMData object
...
other potential arguments; not currently used

Value

  • A list with the following components:
  • overall.chithe test statistic; sum of the statistics for each group
  • overall.pp-value of the test
  • individuala list of the results of the test applied to each group separately:
    • chi.sq the test statistic for the group
    • p p-value for the group

Details

The assumption of marginal compatibility (AKA interpretability) implies that the marginal probability of response does not depend on clustersize. Stefanescu and Turnbull (2003), and Pang and Kuk (2007) developed a Cochran-Armitage type test for trend in the marginal probability of success as a function of the clustersize. mc.test.chisq implements a generalization of that test extending it to multiple treatment groups.

References

Stefanescu, C. & Turnbull, B. W. (2003) Likelihood inference for exchangeable binary data with varying cluster sizes. Biometrics, 59, 18-24 Pang, Z. & Kuk, A. (2007) Test of marginal compatibility and smoothing methods for exchangeable binary data with unequal cluster sizes. Biometrics, 63, 218-227

See Also

CBData for constructing a CBData object, mc.est for estimating the distribution under marginal compatibility.

Examples

Run this code
data(shelltox)
mc.test.chisq(shelltox)

Run the code above in your browser using DataLab