Learn R Programming

CorrBin (version 1.5)

unwrap: Unwrap a clustered object

Description

unwrap is a utility function that reformats a CBData or CMData object so that each row is one observation (instead of one or more clusters). A new `ID' variable is added to indicate clusters. This form can be useful for setting up the data for a different package.

Usage

unwrap(object, ...)

# S3 method for CBData unwrap(object, ...)

# S3 method for CMData unwrap(object, ...)

Arguments

object

a CBData object

other potential arguments; not currently used

Value

For uwrap.CBData: a data frame with one row for each cluster element (having a binary outcome) with the following standardized column names

Trt

factor, the treatment group

ClusterSize

numeric, the cluster size

ID

factor, each level representing a different cluster

Resp

numeric with 0/1 values, giving the response of the cluster element

For unwrap.CMData: a data frame with one row for each cluster element (having a multinomial outcome) with the following standardized column names

Trt

factor, the treatment group

ClusterSize

numeric, the cluster size

ID

factor, each level representing a different cluster

Resp

numeric with integer values giving the response type of the cluster element

Examples

Run this code
# NOT RUN {
data(shelltox)
ush <- unwrap(shelltox)
head(ush)
data(dehp)
dehp.long <- unwrap(dehp)
head(dehp.long)
# }

Run the code above in your browser using DataLab