Learn R Programming

CorrBin (version 1.3)

GEE.trend.test: GEE-based trend test

Description

GEE.trend.test implements a GEE based test for linear increasing trend for correlated binary data.

Usage

GEE.trend.test(cbdata, scale.method = c("fixed", "trend", "all"))

Arguments

cbdata
a CBData object
scale.method
character string specifying the assumption about the change in the overdispersion (scale) parameter across the treatment groups: "fixed" - constant scale parameter (default); "trend" - linear trend for the log of the scale parameter; "all" - sep

Value

  • A list with components
  • statisticnumeric, the value of the test statistic
  • p.valnumeric, asymptotic one-sided p-value of the test

Details

The actual work is performed by the geese function of the geepack library. This function only provides a convenient wrapper to obtain the results in the same format as RS.trend.test and SO.trend.test. The implementation aims for testing for increasing trend, and a one-sided p-value is reported. The test statistic is asymptotically normally distributed, and a two-sided p-value can be easily computed if needed.

See Also

RS.trend.test, SO.trend.test for alternative tests; CBData for constructing a CBData object.

Examples

Run this code
data(shelltox)
GEE.trend.test(shelltox, "trend")

Run the code above in your browser using DataLab