p.valnumeric, asymptotic one-sided p-value of the test
Details
The test is based on calculating a design effect for each cluster by
dividing the observed variability by the one expected under independence. The
number of responses and the cluster size are then divided by the design effect,
and a Cochran-Armitage type test statistic is computed based on these adjusted
values.
The implementation aims for testing for increasing trend, and a one-sided
p-value is reported. The test statistic is asymptotically normally distributed,
and a two-sided p-value can be easily computed if needed.
References
Rao, J. N. K. & Scott, A. J. A (1992) Simple Method for the Analysis of Clustered Data Biometrics, 48, 577-586.