mc.test.chisq tests whether thee assumption of reproducibility is violated
in the data.mc.test.chisq(cbdata)CBData objectmc.test.chisq implements a generalization of that test extending it to multiple treatment groups.CBData for constructing a CBData object, mc.est for estimating the distribution
under marginal compatibility.data(shelltox)
mc.test.chisq(shelltox)Run the code above in your browser using DataLab