For uwrap.CBData: a data frame with one row for each cluster element (having a binary
outcome) with the following standardized column names
Trtfactor, the treatment group
ClusterSizenumeric, the cluster size
IDfactor, each level representing a different cluster
Respnumeric with 0/1 values, giving the response of the cluster
element
For unwrap.CMData: a data frame with one row for each cluster element (having a multinomial
outcome) with the following standardized column names
Trtfactor, the treatment group
ClusterSizenumeric, the cluster size
IDfactor, each level representing a different cluster
Respnumeric with integer values giving the response type of the cluster
element