unwrap.CBData is a utility function that reformats a
CBData object so that each row is one observation (instead
of one or more clusters). A new `ID' variable is added to
indicate clusters. This form can be useful for setting up
the data for a different package.
unwrap.CMData is a utility function that reformats a
CMData object so that each row is one observation (instead
of one or more clusters). A new `ID' variable is added to
indicate clusters. This form can be useful for setting up
the data for a different package.
Usage
unwrap(object, ...)
## S3 method for class 'CBData':
unwrap(object, ...)
## S3 method for class 'CMData':
unwrap(object, ...)